<?php

/*
 **************************************
 *
 * includes/mysql.class.php
 * -------------
 *
 * last modified:	2016-01-28
 * -------------
 *
 * project:	chCounter
 * version:	3.1.1
 * copyright:	 2005 Christoph Bachner - modified to use mysqli
 * license:	GPL vs2.0 or higher [ see docs/license.txt ]
 * contact:	www.christoph-bachner.net
 *
 **************************************
*/



class chC_mysql
{
	var $query_result;
	var $statement;
	var $connection_id;
	var $queries = 0;
	var $accepted_errors = '';
	var $statements = array();
	var $debug = TRUE;
	var $die_on_error = TRUE;
	var $errors = array();
	var $repaired = array();


	function __construct( $db_server, $db_user, $db_passwort, $db_database = FALSE, $debug = '', $force_new_connection = FALSE )
	{
		if( $debug == 'DEBUG_OFF' )
		{
			$this->debug = FALSE;
		}
		elseif( $debug == 'DEBUG_ON' )
		{
			$this->debug = TRUE;

		} 
		//$this->connection_id = @mysql_connect( $db_server, $db_user, $db_passwort, $force_new_connection ) OR $this->_handle_error();
		$this->connection_id = @mysqli_connect( $db_server, $db_user, $db_passwort ) OR $this->_handle_error();
		if( $db_database != FALSE )
		{
			@mysqli_select_db( $db_database ) OR $this->_handle_error();
		}
	}

	function _handle_error( $statement = FALSE )
	{
		$this->errors[] = array(
			'statement'	=> $statement,
			'errno'		=> mysqli_errno($this->connection_id),
			'error'		=> mysqli_error($this->connection_id)
		);
		
		if( $this->debug == FALSE || ( mysqli_errno($this->connection_id) != 0 && is_int( strpos( $this->accepted_errors, (string) mysqli_errno($this->connection_id) ) ) ) )
		{
			return FALSE;
		}


		if( $this->debug == TRUE )
		{
			print "<b>chCounter: MySQL error!</b><br />\n";
			if( $statement != FALSE )
			{
				print "SQL query:<br />\n"
				."<ul style=\"margin-top:5px; margin-bottom:5px\">\n"
				."<li><i>".$statement."</i></li>\n"
				."</ul>\n<br />\n";
			}
			print "Error number: ".mysqli_errno($this->connection_id)."<br />\n".mysqli_error($this->connection_id)."\n";
			if( $this->die_on_error == TRUE )
			{
				die( "<br />\n<i>Script stopped.</i>" );
			}
		}
		elseif( $this->die_on_error == TRUE )
		{
			exit;
		}
	}
	
	function _repair_table( $statement )
	{
		$tabellen = array(
			strtolower( CHC_TABLE_CONFIG ),
			strtolower( CHC_TABLE_DATA ),
			strtolower( CHC_TABLE_LOG_DATA ),
			strtolower( CHC_TABLE_COUNTED_USERS ),
			strtolower( CHC_TABLE_IGNORED_USERS ),
			strtolower( CHC_TABLE_ONLINE_USERS ),
			strtolower( CHC_TABLE_ACCESS ),
			strtolower( CHC_TABLE_SCREEN_RESOLUTIONS ),
			strtolower( CHC_TABLE_USER_AGENTS ),
			strtolower( CHC_TABLE_SEARCH_ENGINES ),
			strtolower( CHC_TABLE_REFERRERS ),
			strtolower( CHC_TABLE_LOCALE_INFORMATION ),
			strtolower( CHC_TABLE_PAGES )
		);
		if( $count = preg_match_all( '/('. implode( '|', $tabellen ) .')/i', $statement, $matches ) )
		{
			$nr = 0;
			for( $i = 0; $i < $count; $i++ )
			{
				if( !isset( $this->repaired[$matches[1][$i]] ) )
				{
					$this->query( 'REPAIR TABLE `'. $matches[1][$i] .'`;' );
					$this->repaired[$matches[1][$i]] = TRUE;
					$nr++;
				}
			}
			if( $nr > 0 )
			{
				return TRUE;
			}
		}
		return FALSE;		
	}
	
	
	

	function set_debug_mode( $mode )
	{
		$this->debug = ( $mode == 'OFF' ) ? FALSE : TRUE;
	}

	function is_connected()
	{
		if( $this->connection_id == FALSE )
		{
			return FALSE;
		}
		else
		{
			return mysqli_ping( $this->connection_id );
		}
	}

	function get_errors()
	{
		return $this->errors;
	}

	function reset_errors()
	{
		$this->errors = array();
	}

	function set_accepted_errors( $errors )
	{
		$this->accepted_errors = (string) $errors;
	}

	function escape_string( $string )
	{
		return mysqli_real_escape_string( $this->connection_id, $string );
	}

	function query( $statement )
	{
		$this->query_result = @mysqli_query( $this->connection_id, $statement  );
		$this->queries++;
		if( mysqli_errno($this->connection_id) )
		{
			if( mysqli_errno($this->connection_id) == 1016 || mysqli_errno($this->connection_id) == 1030 )
			{
				$return = $this->_repair_table( $statement );
				if( $return == TRUE )
				{
					$this->query_result = @mysqli_query( $this->connection_id, $statement );
				}
				else
				{
					$this->_handle_error( $statement );
				}
			}
			else
			{
				$this->_handle_error( $statement );
			}
		}
		$this->statements[] = $statement;
		return $this->query_result;
	}

	function fetch_array( $query_result = FALSE, $all = FALSE )
	{
		return $this->_fetch( 'array', $query_result, $all );
	}

	function fetch_assoc( $query_result = FALSE, $all = FALSE )
	{
		return $this->_fetch( 'assoc', $query_result, $all );
	}

	function fetch_row ( $query_result = FALSE, $all = FALSE )
	{
		return $this->_fetch( 'row', $query_result, $all );
	}

	function _fetch( $type, $query_result, $all )
	{
		if( $query_result == FALSE )
		{
			$query_result = $this->query_result;
		}

		if( $all == FALSE )
		{
			return eval ( 'return @mysqli_fetch_'.$type.'( $query_result );' );
		}
		else
		{
			$array = array();
			for($i = 0; $i < @mysqli_num_rows( $query_result ); $i++)
			{
			 	eval( '$array[$i] = @mysqli_fetch_'.$type.'( $query_result );' );
			}
			return $array;
		}
	}

	function num_rows( $query_result = FALSE )
	{
		return ( $query_result != FALSE ) ? @mysqli_num_rows( $query_result ) : @mysqli_num_rows( $this->query_result );
	}

	function insert_id()
	{
		return @mysqli_insert_id($this->connection_id);
	}

	function affected_rows()
	{
		return @mysqli_affected_rows($this->connection_id);
	}

	function get_number_of_queries()
	{
		return $this->queries;
	}

	function get_last_query()
	{
		return $this->statements[count($this->statements) -1];
	}

	function free_result()
	{
		@mysqli_free_result( $this->query_result );
	}

	function close()
	{
		return @mysqli_close( $this->connection_id );
	}
}

?>
